library hud;

import 'dart:html';
import 'dart:convert' as C;
import 'dart:collection';
import 'dart:async';
import 'package:animation/animation.dart';
import 'package:uuid/uuid_client.dart';
import 'package:intl/intl.dart';

part 'src/parts/menu.dart';
part 'src/parts/tooltip.dart';
part 'src/parts/icon.dart';
part 'src/parts/notification.dart';
part 'src/parts/container.dart';
part 'src/parts/header.dart';
part 'src/parts/prompt.dart';
part 'src/parts/authentication.dart';


///
///
/// The HUD implements UI elements to show stuff (and do things)
///
///


initializeHud() {
  // Start new MutationObserver for DOM manipulation
  MutationObserver observer = new MutationObserver(_mutation);
  observer.observe(querySelector('body'), childList: true, subtree: true);

  // Initialize HudParts
  Tooltip.initialize();
  Header.initialize();
  Notifications.initialize();
  Container.initialize();
  PopupButton.initialize();
  MenuHandler.initialize();
  Prompt.initialize();
}


// Send off mutations to HudParts
// TODO: Better registration.
_mutation(mutations, observer) {
  PopupButton._mutation(mutations, observer);
  Tooltip._mutation(mutations, observer);
}


abstract class Page {
    void showPage();
}


Element findClosestAncestor(ancestorTagName, element) {
  Element parent = element.parent;
  while (parent.tagName.toLowerCase() != ancestorTagName.toLowerCase()) {
    parent = parent.parent;
    if (parent == null) {
      return element;
    }
  }
  return parent;
}


httpGet(String url, Map map, Function callback) {
  String method = 'POST';
  if (map == null) method = 'GET';
  HttpRequest.request(url, method: method, sendData: C.JSON.encode(map), requestHeaders: {
      'Content-Type': 'application/json'
    }).timeout(new Duration(seconds: 5)).then((HttpRequest req) {
      callback(req);
    }).catchError((e) {
      callback(e);
    });
}


Future<HttpRequest> httpReq(String url, {Map data}) {
  String method = 'POST';
  if (data == null) method = 'GET';
  return HttpRequest.request(url, method: method, sendData: C.JSON.encode(data), requestHeaders: {
      'Content-Type': 'application/json'
    }).timeout(new Duration(seconds: 5));
}

