import 'dart:html';

import '../../_hud.dart';


void main() {

  // This initializes handlers and such associated with the Shuttle Hud,
  // including, but not limited to:
  // * Tooltips
  // * Notifications
  // * Shades & Prompts
  //   (including default Prompts)
  initializeHud();
  
  
  
  // Get a new Authenticator instance, just give it the address to a Satellite.
  Authenticator a = new Authenticator('http://192.168.254.203:100');

  
  
  // Next, the page elements that will be used to navigate/render 
  // the various page.
  
  // We're gonna wrap all this inside a div element. The 'design/style' that we're 
  // testing with uses this to help with page responsiveness.
  Element b = querySelector('#outer');

  
  
  // Menus contain MenuObjects.
  //
  // This menu uses MainMenuObjects, which have an icon, page url, and tooltip.
  // When clicked, they load a new page.
  
  b.insertAdjacentElement('beforeEnd', new DivElement()..id = 'page-menu');

  Menu main_menu = new Menu('page-menu', '#page-menu')
      ..addMenuObject(
              // MainMenuObjects navigate through different pages
              // icon_name, page_id, tooltip
          new MainMenuObject('earth', 'PageTest', 'Page Test Tool-tip'))
      
      ..addMenuObject(
          new MainMenuObject('film', 'PartsTest', 'Tooltip test, again. ' +
              'This time with a super super long line. ' +
              '<br><strong>Tooltips can have line returns and emphasis, ' + 
              'too by using html tags</strong>'))
              
       // Don't forget to build the menu!
       // This way, you can allocate different menus to the same parent element
       // and load them when necessary. Without building, the menu is invisible.
       // Building the menu also clears the parent container of any existing menus.
       ..build();

       
  
  // Page Header
  //
  // Page headers have control over the page title and page-icon objects. They are 
  // optional, but is a good example of a simple 'Shuttle Part'.
  
  b.insertAdjacentElement('beforeEnd', new DivElement()..id = 'page-icon');
  b.insertAdjacentElement('beforeEnd', new DivElement()..id = 'page-title');
  
  Header header = new Header('#page-title', '#page-icon')
    ..change(text: 'Test page 1',
        icon: 'delivery', color: 'lightgoldenrod');
  
  
  
  // Sub Menu 
  //
  // This sub-menu includes:
  // * Prompt & Shade
  // * PopupButtons
  
  b.insertAdjacentElement('beforeEnd', new DivElement()..id = 'sub-menu');
  
  Menu sub_menu = new Menu('sub-menu', '#sub-menu')
    ..addMenuObject(
            // PopupButtons do whatever you want, jut give a click_function
            // icon_name, tool_tip, click_function
        new PopupButton('news', 'View the news', (PopupButton b) {
          new Notifications('It\'s sunny outside!');
        }))
    
    ..addMenuObject(new PopupButton('times-outline', 'View a prompt', (PopupButton b) {
          Prompt p = new Prompt();
          p..title = 'This is a prompt.'
            ..body = 'Prompts shade and bring information to the user\'s attention'
            ..getMenu().addMenuObject(
                new PopupButton('thumbs-okay', 'Okay, got it!', (b) { Prompt.hide(p); }))
            ..show();
        }))
    
    ..addMenuObject(
        new PopupButton('user', 'User information', (PopupButton b) {
          a.showUserInfoPrompt();      
        }))
        
    ..build();
  
  
  
  // Page Container
  //
  // Containers are a handy way of inserting some html into an element that is dynamically
  // loaded from another source. It's input should be valid HTML. While loading, it handles
  // the http requests asyncronously with a nice loading spinner. You can alternatively call
  // .showAsLoading manually which will change the innerHtml to the loading spinner.
  
  b.insertAdjacentElement('beforeEnd', new DivElement()..id = 'page-container');
  
  Container c = new Container.fromSelector('#page-container')
    ..showAsLoading();
  
  Prompt.hideAll();
  

}
